import { BaseListener, BaseEntity, BaseEvent, BaseEntityType } from "../BaseEntity";
import { DiagramEngine } from "../DiagramEngine";
import { LinkModel } from "./LinkModel";
import { NodeModel } from "./NodeModel";
import { BaseModel, BaseModelListener } from "./BaseModel";
/**
 * @author Dylan Vorster
 */
export interface DiagramListener extends BaseListener {
    nodesUpdated?(event: BaseEvent & {
        node: NodeModel;
        isCreated: boolean;
    }): void;
    linksUpdated?(event: BaseEvent & {
        link: LinkModel;
        isCreated: boolean;
    }): void;
    offsetUpdated?(event: BaseEvent<DiagramModel> & {
        offsetX: number;
        offsetY: number;
    }): void;
    gridUpdated?(event: BaseEvent<DiagramModel> & {
        size: number;
    }): void;
    validLinkCreated?(event: BaseEvent & {
        link: LinkModel;
    }): void;
    validLinkDeleted?(event: BaseEvent & {
        link: LinkModel;
    }): void;
}
/**
 * @author Dylan Vorster, Iliya Krastinkov
 *
 * Responsibility: Entities collection.
 */
export declare class DiagramModel extends BaseEntity<DiagramListener> {
    links: {
        [s: string]: LinkModel;
    };
    nodes: {
        [s: string]: NodeModel;
    };
    rendered: boolean;
    offsetX: number;
    offsetY: number;
    gridSize: number;
    constructor();
    setGridSize(size?: number): void;
    getGridPosition(pos: any): any;
    serialize(): any;
    deSerialize(object: any, diagramEngine: DiagramEngine): void;
    clearSelection(ignore?: BaseModel<BaseEntity, BaseModelListener> | null): void;
    getSelectedItems(...filters: BaseEntityType[]): BaseModel<BaseEntity, BaseModelListener>[];
    setOffset(offsetX: number, offsetY: number): void;
    getOffsetY(): number;
    getOffsetX(): number;
    getNode(node: string | NodeModel): NodeModel | null;
    getLink(link: string | LinkModel): LinkModel | null;
    addAll(...models: BaseModel[]): BaseModel[];
    addLink(link: LinkModel): LinkModel;
    addNode(node: NodeModel): NodeModel;
    removeLink(link: LinkModel | string): void;
    removeNode(node: NodeModel | string): void;
    getLinks(): {
        [s: string]: LinkModel;
    };
    getNodes(): {
        [s: string]: NodeModel;
    };
    validLinkCreated(link: LinkModel): void;
}
